@@ -88,14 +88,6 @@ Pass the database name.
 
 Pass the database driver.
 
-=item B<user>
-
-Pass the database user for the connect.
-
-=item B<password>
-
-Pass the users password.
-
 =item B<host>
 
 Pass the hostname where the database is running.
@@ -104,6 +96,14 @@ Pass the hostname where the database is running.
 
 Pass the port where the database is listened.
 
+=item B<user>
+
+Pass the database user for the connect.
+
+=item B<password>
+
+Pass the users password.
+
 =item B<table> and B<columns>
 
 With this options you can pass the table name for the insert and the columns.
@@ -171,7 +171,7 @@ This option is set to 1 on default.
 
 =item B<reconnect>
 
-C<reconnect> is deprecated!
+C<reconnect> is deprecated and not usable!
 
 =item B<dbi_params>
 
